
## vector-db
- JinaEmbeddings: https://python.langchain.com/v0.2/docs/integrations/text_embedding/jina/ 
- tidb: https://docs.pingcap.com/tidbcloud/vector-search-integrate-with-langchain 



# reference
- https://educationbot.cerebrium.ai/
- https://github.com/CerebriumAI/examples/tree/master/19-voice-rag-agent
- https://github.com/CerebriumAI/educator-client
- https://www.cerebrium.ai/blog/creating-a-realtime-rag-voice-agent